% AR-z spectrum
%-----input----------------------------------------------------------------
% xm - data, requires same time interval
% dt - time interval
% zp - length of data or zero-padding numbers
% Q - Q factor, default is infinite (use unit circle)
%-----output---------------------------------------------------------------
% gg - frequency solution
% rr - damping coefficients solution
% ff - fourier frequency axis
% dist - the distance between the circle (corresponds to Q factor) and
% the poles
% unc - circle corresponds to Q
%--------------------------------------------------------------------------
% Reference Paper  Chao, B. F., & Gilbert, F. (1980).
%--------------------------------------------------------------------------

function [gg,rr,ff,dist,poles,unc]=arz_zp_hua(xm,dt,zp,Q)

%resize the input
if size(xm,1)>size(xm,2)
    xm=xm';
end

N=length(xm);

NN=zp-fix(zp/2);% get the first half points

f0=(0:zp-1)./(zp)./(dt); % Unit:HZ
ff=f0(1:NN);
samplerate=1/dt;

%Q=w/(2*beta), radius=exp(-beta), and we need to consider the unit
if isempty(Q)
    radius=1;
else
    radius=abs(exp(- (2.*pi.*ff.*dt./(2.*Q))));
end


J=1;

NK=N-J*2; % the length of the new series
x1=xm(1+J*2:N).*2.*hanning(NK)';x2=xm(1+J:N-J).*2.*hanning(NK)';x3=xm(1:N-J*2).*2.*hanning(NK)';


%the hanning window is chosen
im1=(fft(x1,zp)).*2/(NK);  
im2=(fft(x2,zp)).*2/(NK);
im3=(fft(x3,zp)).*2/(NK);

    for i=1:NN
%         disp([num2str(i),'/',num2str(NN)])
            if i==1
                wm1=im1(i:i+2); % one-point estimate
                wm2=im2(i:i+2);
                wm3=im3(i:i+2);

            elseif i==NN
                wm1=im1(i-2:i);% one-point estimate
                wm2=im2(i-2:i);
                wm3=im3(i-2:i);
            else
                wm1=im1(i-1:i+1);% three-point estimate
                wm2=im2(i-1:i+1);
                wm3=im3(i-1:i+1);
            end
        
        B=[real(wm2)' real(wm3)';
            imag(wm2)' imag(wm3)'];
        G=[real(wm1)';imag(wm1)'];

        %Check the value of S.
        %If we get the positive S, that's from the bad cond# for the
        %matrix,so we have to check and throw away
        
        
        S=pinv(B'*B)*B'*G;
        
        if  S(2)>0   
            g(i)=nan;
            r(i)=nan;
            sigma(i)=complex(nan);
            poles(i)=complex(nan);

        else
            g(i)=acos(S(1)/2/sqrt(-S(2)))/2/pi/dt/J;  % Unit:Hz; you can changeed it as you want
            r(i)=-0.5*log(-S(2))/dt/J; % attenuation factor
            sigma(i)=complex(2.*pi.*g(i)+j.*r(i));
            poles(i)=complex(exp(j.*sigma(i).*dt));

        end
       
    end
        
g=abs(g);
    
gg=g;
rr=r;

% sigma=2.*pi.*g+j.*(r);
% poles=exp(j.*sigma.*J.*dt);
unc=radius.*exp(j.*2.*pi.*ff.*dt);

dist=log(1./(abs(unc-poles).^2));
end


    

