clc;clear;close all
% Applied function: complex_EOF.m | angle360.m
%% Parameters
% Example 3 from PPT reference: 
% "Complex Empirical Orthogonal Functions Applied to Earth Sciences" by David Garcia-Garcia

lon=180;dl=180/4;
lat=89;
t = 0:50; %time
f = 1/12; %frequency

% map=colormap('jet');
% map=[1 1 1;map;1 1 1];

% add random noise
x1 = cos(2*pi*f*(t-0))*20 + randn(1,length(t));
x2 = cos(2*pi*f*(t-3))*20 + randn(1,length(t));
x3 = cos(2*pi*f*(t-6))*20 + randn(1,length(t));
x4 = cos(2*pi*f*(t-9))*20 + randn(1,length(t));

for k=1:50
MC(1:lat, 1:dl        ,k)=(x1(k))*ones(lat,dl);
MC(1:lat, dl+1:dl*2   ,k)=(x2(k))*ones(lat,dl);
MC(1:lat, dl*2+1:dl*3 ,k)=(x3(k))*ones(lat,dl);
MC(1:lat, dl*3+1:dl*4 ,k)=(x4(k))*ones(lat,dl);

temp=MC(:,:,k);
MMM(k,:)=temp(:)'; %change to 1-D 
end

% Arranged Matrix (nxm where n for time, m for space)
% complex_EOF(Martrix, mode_nums)
[eig_val,eig_val_ratio,spatial,time]=complex_EOF(MMM,4);

%% Recover

% generate grid
[Lon,Lat] = meshgrid (1:lon,-88:2:88);

% get first mode
for nn=1:2
Modes(:,:,nn)=reshape(spatial(:,nn),lat,lon);

% Spatial part
S_mag    = abs(Modes(:,:,nn));
S_pha360 = angle360(Modes(:,:,nn));

% Time part
T_mag    = abs(time(:,nn));
T_pha    = unwrap(angle(time(:,nn)),pi).*180./pi;


figure
% space mag
subplot(4,2,[1 3 5]);
surf(Lon,Lat,S_mag,'EdgeColor', 'none');
view(0,90);

title({['Mode ',num2str(nn)],['Magnitude',' (',num2str(round(eig_val_ratio(nn),1)),'%)']})
xlabel('Lon');ylabel('Lat');

colorbar
colormap jet
caxis([0 1])

% time mag
subplot(4,2,7)
plot(T_mag,'linewidth',1.5);axis tight

subplot(4,2,[2 4 6]);
surf(Lon,Lat,S_pha360,'EdgeColor', 'none');
view(0,90);

title({['Mode ',num2str(nn)],['Phase',' (',num2str(round(eig_val_ratio(nn),1)),'%)']})
xlabel('Lon');ylabel('Lat');

colorbar
colormap jet
caxis([0 360])

subplot(4,2,8)
plot(T_pha,'linewidth',1.5);axis tight;

set(gcf,'position',[100 100 1000 600]);
end



%% draw animation for 20 ticks
figure;
s=surf(MC(:,:,1),'EdgeColor','none');
colormap('jet')
colorbar
caxis([-20,20]);

xlabel("Lon");ylabel("Lat");zlabel("Amplitude");

for k=1:20
set(s,'zdata',MC(:,:,k))
pause(0.3)
drawnow
end


