clc;clear;close all
% Applied function: conventional_EOF.m
%% Parameters
% Example 2 from PPT reference: 
% "Complex Empirical Orthogonal Functions Applied to Earth Sciences" by David Garcia-Garcia

lon=180;dl=180/4;
lat=89;
t = 0:50; %time
f = 1/12; %frequency

% add random noise
x1 = cos(2*pi*f*t)*20     + randn(1,length(t));
x2 = cos(2*pi*f*t)*5      + randn(1,length(t));
x3 = cos(2*pi*f*t)*(-15)  + randn(1,length(t));
x4 = cos(2*pi*f*t)*0      + randn(1,length(t));

for k=1:50
MC(1:lat, 1:dl        ,k)=(x1(k))*ones(lat,dl);
MC(1:lat, dl+1:dl*2   ,k)=(x2(k))*ones(lat,dl);
MC(1:lat, dl*2+1:dl*3 ,k)=(x3(k))*ones(lat,dl);
MC(1:lat, dl*3+1:dl*4 ,k)=(x4(k))*ones(lat,dl);

temp=MC(:,:,k);
MMM(k,:)=temp(:)'; %change to 1-D 
end

% Arranged Matrix (nxm where n for time, m for space)
% conventional_EOF(Martrix, mode_nums)
[eig_val,eig_val_ratio,spatial,time]=conventional_EOF(MMM,4);

%% Recover

% generate grid
[Lon,Lat] = meshgrid (1:lon,-88:2:88);

% get first two modes
for nn=1:2
Modes(:,:,nn) = reshape(spatial(:,nn),lat,lon);
end

%% Draw figures

figure
% ---Mode 1--- 
% space
subplot(4,2,[1 3 5]);
surf(Lon,Lat,Modes(:,:,1),'EdgeColor', 'none');
view(0,90) ;

title({'Mode 1',['Magnitude',' (',num2str(round(eig_val_ratio(1),1)),'%)']});
xlabel('Lon');ylabel('Lat');

colorbar
colormap jet
caxis([-1 1])

% time
subplot(4,2,7)
plot(time(:,1),'linewidth',1.5);axis tight
xlabel('Time');

% ---Mode 2--- 
% space
subplot(4,2,[2 4 6]);
surf(Lon,Lat,Modes(:,:,2),'EdgeColor', 'none');
view(0,90) ;

title({['Mode 2'],['Magnitude',' (',num2str(round(eig_val_ratio(2),1)),'%)']});
xlabel('Lon');ylabel('Lat');

colorbar
colormap jet
caxis([-1 1])

% time
subplot(4,2,8)
plot(time(:,2),'linewidth',1.5);axis tight
xlabel('Time');

set(gcf,'position',[100 80 1000 700]);

%% draw animation for 20 ticks
figure;
s=surf(MC(:,:,1),'EdgeColor','none');
colormap('jet')
colorbar
caxis([-25,25]);
zlim([-25,25]);
xlabel("Lon");ylabel("Lat");zlabel("Amplitude");

for k=1:20
set(s,'zdata',MC(:,:,k))
pause(0.3)
drawnow
end
